DeviceClassMatcher

Trait DeviceClassMatcher 

pub trait DeviceClassMatcher<DeviceClass> {
    // Required method
    fn device_class_matches(&self, device_class: &DeviceClass) -> bool;
}
Provides matching functionality for the device class of a device installed in the netstack.

Required Methods

fn device_class_matches(&self, device_class: &DeviceClass) -> bool

Returns whether the provided device class matches the class of the device.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl DeviceClassMatcher<()> for ()

Implementors