DeviceIdAndNameMatcher

Trait DeviceIdAndNameMatcher 

pub trait DeviceIdAndNameMatcher {
    // Required methods
    fn id_matches(&self, id: &NonZero<u64>) -> bool;
    fn name_matches(&self, name: &str) -> bool;
}
Provides matching functionality for the ID and name of a device installed in the netstack.

Required Methods

fn id_matches(&self, id: &NonZero<u64>) -> bool

Returns whether the provided ID matches the ID of the device.

fn name_matches(&self, name: &str) -> bool

Returns whether the provided name matches the name of the device.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl DeviceIdAndNameMatcher for MonotonicIdentifier

Source

fn id_matches(&self, _id: &NonZero<u64>) -> bool

Source

fn name_matches(&self, _name: &str) -> bool

Implementors