pub enum FrameDestination<L = bool> {
Individual {
local: L,
},
Multicast,
Broadcast,
}Expand description
The type of address used as the destination address in a device-layer frame.
FrameDestination is used to implement RFC 1122 section 3.2.2 and RFC 4443
section 2.4.e, which govern when to avoid sending an ICMP error message for
ICMP and ICMPv6 respectively.
Variants
Individual
A unicast address - one which is neither multicast nor broadcast.
Fields
local: LWhether the frame’s destination address belongs to the receiver.
Multicast
A multicast address; if the addressing scheme supports overlap between
multicast and broadcast, then broadcast addresses should use the
Broadcast variant.
Broadcast
A broadcast address; if the addressing scheme supports overlap between
multicast and broadcast, then broadcast addresses should use the
Broadcast variant.
Implementations
Sourceimpl<L> FrameDestination<L>
impl<L> FrameDestination<L>
Sourcepub fn is_broadcast(self) -> bool
pub fn is_broadcast(self) -> bool
Is this FrameDestination::Broadcast?
Sourceimpl FrameDestination
impl FrameDestination
Sourcepub fn from_dest(destination: Mac, local_mac: Mac) -> FrameDestination
pub fn from_dest(destination: Mac, local_mac: Mac) -> FrameDestination
Creates a FrameDestination from a mac and local_mac destination.
Sourcepub fn check_local(self) -> Option<FrameDestination<()>>
pub fn check_local(self) -> Option<FrameDestination<()>>
Converts this FrameDestination to a LocalFrameDestination.
Returns None if the destination is Individual { local: false },
indicating the packet is not for this host and should be dropped.