pub enum ChecksumRxOffloading {
Offloaded(Option<NonZero<u16>>),
FullyOffloaded,
}Expand description
An indication of the checksums offloaded, if any, for a packet received from a device.
Variants
Offloaded(Option<NonZero<u16>>)
The device offloaded zero or more checksums.
Some(n) can only be used to describe offloading of TCP and UDP
checksums.
FullyOffloaded
The device requires no checksum verification on packet ingress.
NOTE: only intended to be used by the loopback interface.