pub struct NetworkSerializationContext { /* private fields */ }Expand description
A concrete serialization context for the entire network stack.
Implementations
Sourceimpl NetworkSerializationContext
impl NetworkSerializationContext
Sourcepub fn new(
csum_offload_spec: ChecksumOffloadSpec,
) -> NetworkSerializationContext
pub fn new( csum_offload_spec: ChecksumOffloadSpec, ) -> NetworkSerializationContext
Creates a new NetworkSerializationContext with the given checksum offload capabilities.
Sourcepub fn csum_offload_result(self) -> Option<ChecksumOffloadResult>
pub fn csum_offload_result(self) -> Option<ChecksumOffloadResult>
Returns the result of the checksum offloading operation for the current packet, if any.