pub struct ProtocolSpecificOffloadSpec(/* private fields */);Expand description
Indicates that a device supports protocol-specific checksum offloading.
Implementations
Sourceimpl ProtocolSpecificOffloadSpec
impl ProtocolSpecificOffloadSpec
Sourcepub const ETH_IPV4_UDP: ProtocolSpecificOffloadSpec
pub const ETH_IPV4_UDP: ProtocolSpecificOffloadSpec
Ethernet frame with IPv4 header (without options) and UDP payload.
Sourcepub const ETH_IPV4_TCP: ProtocolSpecificOffloadSpec
pub const ETH_IPV4_TCP: ProtocolSpecificOffloadSpec
Ethernet frame with IPv4 header (without options) and TCP payload.
Sourcepub const ETH_IPV6_UDP: ProtocolSpecificOffloadSpec
pub const ETH_IPV6_UDP: ProtocolSpecificOffloadSpec
Ethernet frame with IPv6 header (without extension headers) and UDP payload.
Sourcepub const ETH_IPV6_TCP: ProtocolSpecificOffloadSpec
pub const ETH_IPV6_TCP: ProtocolSpecificOffloadSpec
Ethernet frame with IPv6 header (without extension headers) and TCP payload.
Sourceimpl ProtocolSpecificOffloadSpec
impl ProtocolSpecificOffloadSpec
Sourcepub const fn empty() -> ProtocolSpecificOffloadSpec
pub const fn empty() -> ProtocolSpecificOffloadSpec
Get a flags value with all bits unset.
Sourcepub const fn all() -> ProtocolSpecificOffloadSpec
pub const fn all() -> ProtocolSpecificOffloadSpec
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<ProtocolSpecificOffloadSpec>
pub const fn from_bits(bits: u8) -> Option<ProtocolSpecificOffloadSpec>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> ProtocolSpecificOffloadSpec
pub const fn from_bits_truncate(bits: u8) -> ProtocolSpecificOffloadSpec
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> ProtocolSpecificOffloadSpec
pub const fn from_bits_retain(bits: u8) -> ProtocolSpecificOffloadSpec
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<ProtocolSpecificOffloadSpec>
pub fn from_name(name: &str) -> Option<ProtocolSpecificOffloadSpec>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: ProtocolSpecificOffloadSpec) -> bool
pub const fn intersects(&self, other: ProtocolSpecificOffloadSpec) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: ProtocolSpecificOffloadSpec) -> bool
pub const fn contains(&self, other: ProtocolSpecificOffloadSpec) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: ProtocolSpecificOffloadSpec)
pub fn insert(&mut self, other: ProtocolSpecificOffloadSpec)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: ProtocolSpecificOffloadSpec)
pub fn remove(&mut self, other: ProtocolSpecificOffloadSpec)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: ProtocolSpecificOffloadSpec)
pub fn toggle(&mut self, other: ProtocolSpecificOffloadSpec)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: ProtocolSpecificOffloadSpec, value: bool)
pub fn set(&mut self, other: ProtocolSpecificOffloadSpec, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(
self,
other: ProtocolSpecificOffloadSpec,
) -> ProtocolSpecificOffloadSpec
pub const fn intersection( self, other: ProtocolSpecificOffloadSpec, ) -> ProtocolSpecificOffloadSpec
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(
self,
other: ProtocolSpecificOffloadSpec,
) -> ProtocolSpecificOffloadSpec
pub const fn union( self, other: ProtocolSpecificOffloadSpec, ) -> ProtocolSpecificOffloadSpec
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(
self,
other: ProtocolSpecificOffloadSpec,
) -> ProtocolSpecificOffloadSpec
pub const fn difference( self, other: ProtocolSpecificOffloadSpec, ) -> ProtocolSpecificOffloadSpec
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: ProtocolSpecificOffloadSpec,
) -> ProtocolSpecificOffloadSpec
pub const fn symmetric_difference( self, other: ProtocolSpecificOffloadSpec, ) -> ProtocolSpecificOffloadSpec
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> ProtocolSpecificOffloadSpec
pub const fn complement(self) -> ProtocolSpecificOffloadSpec
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl ProtocolSpecificOffloadSpec
impl ProtocolSpecificOffloadSpec
Sourcepub const fn iter(&self) -> Iter<ProtocolSpecificOffloadSpec>
pub const fn iter(&self) -> Iter<ProtocolSpecificOffloadSpec>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ProtocolSpecificOffloadSpec>
pub const fn iter_names(&self) -> IterNames<ProtocolSpecificOffloadSpec>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl ProtocolSpecificOffloadSpec
impl ProtocolSpecificOffloadSpec
Sourcepub fn tcp_or_udp_over_ipv4() -> ProtocolSpecificOffloadSpec
pub fn tcp_or_udp_over_ipv4() -> ProtocolSpecificOffloadSpec
Creates a ProtocolSpecificOffloadSpec for devices that support
protocol-specific checksum offloading for UDP and TCP packets over IPv4.
This spec does not match when the IPv4 header contains options.
Sourcepub fn tcp_or_udp_over_ipv6() -> ProtocolSpecificOffloadSpec
pub fn tcp_or_udp_over_ipv6() -> ProtocolSpecificOffloadSpec
Creates a ProtocolSpecificOffloadSpec for devices that support
protocol-specific checksum offloading for UDP and TCP packets over IPv6.
This spec does not match when IPv6 contains extension headers.