MatcherBindingsTypes

Trait MatcherBindingsTypes 

pub trait MatcherBindingsTypes {
    type DeviceClass: Clone + Debug;
    type BindingsPacketMatcher: Clone + Debug + InspectableValue;
}
Trait defining required types for matchers provided by bindings.

Allows rules that match on device class to be installed, storing the MatcherBindingsTypes::DeviceClass type at rest, while allowing Netstack3 Core to have Bindings provide the type since it is platform-specific.

Required Associated Types

type DeviceClass: Clone + Debug

The device class type for devices installed in the netstack.

type BindingsPacketMatcher: Clone + Debug + InspectableValue

The type used to represent a custom filter matcher.

Clone is required because filter validator clones rules when installing them.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl MatcherBindingsTypes for netstack3_core::testutil::FakeBindingsCtx

Source

impl<TimerId, Event, State, FrameMeta> MatcherBindingsTypes for netstack3_base::testutil::fake_bindings::FakeBindingsCtx<TimerId, Event, State, FrameMeta>
where TimerId: Debug, Event: Debug,